//                          Software License Agreement
//
// The software supplied herewith by Microchip Technology Incorporated (the "Company")
// for its PICmicro Microcontroller is intended and supplied to you, the Companys
// customer, for use solely and exclusively on Microchip PICmicro Microcontroller
// products.
//
// The software is owned by the Company and/or its supplier, and is protected under
// applicable copyright laws. All rights are reserved. Any use in violation of the
// foregoing restrictions may subject the user to criminal sanctions under applicable
// laws, as well as to civil liability for the breach of the terms and conditions of
// this license.
//
// THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES, WHETHER EXPRESS,
// IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE
// COMPANY SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
// CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
//
// ###############################################################################
// filename:		USB_MAIN.C
//			Sample main program
//
// This file implements a basic interrupt service routine and shows how the
// USB interrupt should be serviced, how InitUSB should be called, and how PutUSB
// should be called.  It may be used as a reference, or as a starting point 
// from which to build an application.  
//
// ###############################################################################
//
// Authors:		Reston Condit, Dan Butler
// Company:		Microchip Technology Inc
//
// Revision:		1.22
// Date:		15 May 2002
// Compiled using:	HI-TECH C 7.87 PL2
// Configuration Bits:	H4 Oscillator, WDT Off, Power up timer off
// Revision History:
// 14 February	2002	RAC Corrected USBSleep and USBActivity to suspend and
//			    unsuspend the SIE respectively
// 25 February 2002	RAC Remote Wakeup initialization was moved from a 
//			    PORTB interrupt to the RA4 pin.  The move was made 
//			    because this firmware uses PORTB for USB status 
//			    outputs.  RA4 is a button on the PICDEM USB board.  
//			    For users who don't have the PICDEM USB PCB, RA4 is 
//			    active low.
// 5 March 2002		RAC Clear <UCTRL: SUSPND> bit in USBActivity rather than 
//			    setting it.
// 15 May 2002		RAC Changed the order that USB interrupts are serviced.
//
//################################################################################
//
// include files:
//	pic.h	        
//	usb.h
//
//###############################################################################

#include <pic.h>
#include "usb.h"
__CONFIG(0x3F3A);  // H4 Oscillator, WDT Off, Power up timer off, Code Protect off

bank1 static volatile bit NOT_RBPU @ 0x81*8+7;
bank3 static volatile unsigned char UCRL @ 0x15;
unsigned char PutEP1 (unsigned char bytes, unsigned char buffer[]);

// Handler for NON-peripheral interrupts
void CoreInterrupt() {
	return;
}

// Handler for PORTB Change interrupt. Perform Remote Wakeup here
void PortBChange() {
	RBIF = 0;
	RemoteWakeup();
	return;
}

// Interrupt service routine. Branch off to different interrupts
interrupt ISR () {
	if (USBIF && USBIE) {
		ServiceUSBInt();
	} else if (RBIF && RBIE) {
		PortBChange();
	} else {
		CoreInterrupt();
	}
}

void main() {
	unsigned char i;
	unsigned char state = 0;
	const unsigned char table [] = {-4, -4, -4, 0, 4, 4, 4, 0, -4, -4};
	unsigned char buffer [4];

	TRISB = 0;
	PORTB = 0;
	for (i = 0; i < 50; i ++);
	InitUSB ();
	while ((USWSTAT & 0x03) != 3);  /* wait here until configured */
	buffer [0] = 0;
	while (1)
	{
		buffer[1] = table [state];
		buffer[2] = table [state+2];
		++state;
		for (i = 0; i < 15; i++)
			while (PutEP1(4, buffer) == 0);
		if (state > 7)
			state = 0;
	}
}
